@@ -26,8 +26,11 @@ from .cis_ip_api_v1 import CisIpApiV1
 from .custom_pages_v1 import CustomPagesV1
 from .dns_record_bulk_v1 import DnsRecordBulkV1
 from .dns_records_v1 import DnsRecordsV1
+from .filters_v1 import FiltersV1
 from .firewall_access_rules_v1 import FirewallAccessRulesV1
+from .filters_v1 import FiltersV1
 from .firewall_api_v1 import FirewallApiV1
+from .firewall_rules_v1 import FirewallRulesV1
 from .global_load_balancer_events_v1 import GlobalLoadBalancerEventsV1
 from .global_load_balancer_monitor_v1 import GlobalLoadBalancerMonitorV1
 from .global_load_balancer_pools_v0 import GlobalLoadBalancerPoolsV0
@@ -47,15 +50,15 @@ from .zone_lockdown_v1 import ZoneLockdownV1
 from .zone_rate_limits_v1 import ZoneRateLimitsV1
 from .zones_settings_v1 import ZonesSettingsV1
 from .zones_v1 import ZonesV1
+from .webhooks_v1 import WebhooksV1
+from .alerts_v1 import AlertsV1
 
 # Private DNS Service Packages
 from .dns_zones_v1 import DnsZonesV1
 from .resource_records_v1 import ResourceRecordsV1
 from .permitted_networks_for_dns_zones_v1 import PermittedNetworksForDnsZonesV1
 from .global_load_balancers_v1 import GlobalLoadBalancersV1
-from .dns_resource_records_v1 import DnsResourceRecordsV1
-from .dns_permitted_networks_v1 import DnsPermittedNetworksV1
-from .dns_global_load_balancers_v1 import DnsGlobalLoadBalancersV1
+from .dns_svcs_v1 import DnsSvcsV1
 
 # Directlink Service Packages
 from .direct_link_v1 import DirectLinkV1
